// intro2d.cpp
// by Glenn G. Chappell
// September 2003
//
// For CS 381
// Introductory 2-D OpenGL/GLUT program

#include <iostream>
using std::cout;
using std::cerr;
using std::endl;
#include <stdlib.h>  // Some versions of MS-Vis C++ have broken <cstdlib>
//using std::exit;
#include <GL/glut.h> // GLUT stuff, includes OpenGL headers as well


// Global variables
// Window/viewport
const int startwinsize = 400; // Starting window width & height, in pixels

// Keyboard
const int ESCKEY = 27;        // ASCII value of escape character


// display
// The GLUT display function
void display()
{
   glClear(GL_COLOR_BUFFER_BIT);

   glColor3d(0.9, 0.1, 0.1);
   glBegin(GL_QUADS);
      glVertex2d(0.1, 0.1);
      glVertex2d(0.9, 0.1);
      glVertex2d(0.9, 0.9);
      glVertex2d(0.1, 0.9);
   glEnd();

   glFlush();
}


// idle
// The GLUT idle function
void idle()
{
   // Print OpenGL errors, if there are any (for debugging)
   if (GLenum err = glGetError())
   {
      cerr << "OpenGL ERROR: " << gluErrorString(err) << endl;
   }
}


// keyboard
// The GLUT keyboard function
void keyboard(unsigned char key, int x, int y)
{
   switch (key)
   {
   case ESCKEY:  // ESC: Quit
      exit(0);
      break;
   }
}


// init
// Initializes GL states
// Called by main after window creation
void init()
{
   glClearColor(1.0, 1.0, 1.0, 0.0);

   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
   gluOrtho2D(0.0, 1.0, 0.0, 1.0);

   glMatrixMode(GL_MODELVIEW);  // Always go back to model/view mode

   // Documentation
   cout << "Introductory 2-D OpenGL/GLUT Program" << endl;
   cout << "by Glenn G. Chappell" << endl;
   cout << "for CS 381, Fall 2003" << endl;
   cout << endl;
   cout << "Esc   Quit" << endl;
   cout << endl;
   cout << "All keys must be pressed in graphics window." << endl;
}


int main(int argc, char ** argv)
{
   // Initialize OpenGL/GLUT
   glutInit(&argc, argv);
   glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB);

   // Make a window
   glutInitWindowSize(startwinsize, startwinsize);
   glutInitWindowPosition(50, 50);
   glutCreateWindow("CS 381 - Introductory 2-D Program");

   // Initialize GL states & register callbacks
   init();
   glutDisplayFunc(display); 
   glutIdleFunc(idle);
   glutKeyboardFunc(keyboard);

   // Do something
   glutMainLoop();

   return 0;
}
